==> kafka-3.6.2-src.tgz: kafka-3.6.2-src/metadata/src/test/java/org/apache/kafka/metadata/migration/CapturingDelegationTokenMigrationClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.metadata.migration;

import org.apache.kafka.common.security.token.delegation.TokenInformation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class CapturingDelegationTokenMigrationClient implements DelegationTokenMigrationClient {
    
    public List<String> deletedDelegationTokens = new ArrayList<>();
    public HashMap<String, TokenInformation> updatedDelegationTokens = new HashMap<>();

    public void reset() {
        deletedDelegationTokens.clear();
        updatedDelegationTokens.clear();
    }


    @Override
    public List<String> getDelegationTokens() {
        return new ArrayList<String>();
    }

    @Override
    public ZkMigrationLeadershipState deleteDelegationToken(String tokenId, ZkMigrationLeadershipState state) {
        deletedDelegationTokens.add(tokenId);
        return state;
    }

    @Override
    public ZkMigrationLeadershipState writeDelegationToken(String tokenId, TokenInformation tokenInformation, ZkMigrationLeadershipState state) {
        updatedDelegationTokens.put(tokenId, tokenInformation);
        return state;
    }

}

==> kafka-3.9.0-src.tgz: kafka-3.9.0-src/metadata/src/test/java/org/apache/kafka/metadata/migration/CapturingDelegationTokenMigrationClient.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.metadata.migration;

import org.apache.kafka.common.security.token.delegation.TokenInformation;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class CapturingDelegationTokenMigrationClient implements DelegationTokenMigrationClient {
    
    public List<String> deletedDelegationTokens = new ArrayList<>();
    public HashMap<String, TokenInformation> updatedDelegationTokens = new HashMap<>();

    public void reset() {
        deletedDelegationTokens.clear();
        updatedDelegationTokens.clear();
    }


    @Override
    public List<String> getDelegationTokens() {
        return new ArrayList<>();
    }

    @Override
    public ZkMigrationLeadershipState deleteDelegationToken(String tokenId, ZkMigrationLeadershipState state) {
        deletedDelegationTokens.add(tokenId);
        return state;
    }

    @Override
    public ZkMigrationLeadershipState writeDelegationToken(String tokenId, TokenInformation tokenInformation, ZkMigrationLeadershipState state) {
        updatedDelegationTokens.put(tokenId, tokenInformation);
        return state;
    }

}
